Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the registry v1 API group +kubebuilder:object:generate=true +groupName=registry.apicur.io
Index ¶
- Variables
- type ApicurioRegistry
- type ApicurioRegistryList
- type ApicurioRegistryObjectMeta
- type ApicurioRegistryPodSpec
- type ApicurioRegistryPodTemplateSpec
- type ApicurioRegistrySpec
- type ApicurioRegistrySpecConfiguration
- type ApicurioRegistrySpecConfigurationDataSource
- type ApicurioRegistrySpecConfigurationKafkaSecurity
- type ApicurioRegistrySpecConfigurationKafkaSecurityScram
- type ApicurioRegistrySpecConfigurationKafkaSecurityTls
- type ApicurioRegistrySpecConfigurationKafkasql
- type ApicurioRegistrySpecConfigurationSecurity
- type ApicurioRegistrySpecConfigurationSecurityHttps
- type ApicurioRegistrySpecConfigurationSecurityKeycloak
- type ApicurioRegistrySpecConfigurationSql
- type ApicurioRegistrySpecConfigurationUI
- type ApicurioRegistrySpecDeployment
- type ApicurioRegistrySpecDeploymentManagedResources
- type ApicurioRegistrySpecDeploymentMetadata
- type ApicurioRegistryStatus
- type ApicurioRegistryStatusInfo
- type ApicurioRegistryStatusManagedResource
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "registry.apicur.io", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ApicurioRegistry ¶
type ApicurioRegistry struct {
meta.TypeMeta `json:",inline"`
meta.ObjectMeta `json:"metadata,omitempty"`
Spec ApicurioRegistrySpec `json:"spec,omitempty"`
Status ApicurioRegistryStatus `json:"status,omitempty"`
}
ApicurioRegistry represents an Apicurio Registry instance +kubebuilder:object:root=true +kubebuilder:subresource:status
func (*ApicurioRegistry) DeepCopy ¶
func (in *ApicurioRegistry) DeepCopy() *ApicurioRegistry
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistry.
func (*ApicurioRegistry) DeepCopyInto ¶
func (in *ApicurioRegistry) DeepCopyInto(out *ApicurioRegistry)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ApicurioRegistry) DeepCopyObject ¶
func (in *ApicurioRegistry) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ApicurioRegistryList ¶
type ApicurioRegistryList struct {
meta.TypeMeta `json:",inline"`
meta.ListMeta `json:"metadata,omitempty"`
Items []ApicurioRegistry `json:"items"`
}
ApicurioRegistryList contains a list of ApicurioRegistry +kubebuilder:object:root=true
func (*ApicurioRegistryList) DeepCopy ¶
func (in *ApicurioRegistryList) DeepCopy() *ApicurioRegistryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryList.
func (*ApicurioRegistryList) DeepCopyInto ¶
func (in *ApicurioRegistryList) DeepCopyInto(out *ApicurioRegistryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ApicurioRegistryList) DeepCopyObject ¶
func (in *ApicurioRegistryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ApicurioRegistryObjectMeta ¶ added in v1.1.0
type ApicurioRegistryObjectMeta struct {
// +optional
Name string `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
// +optional
GenerateName string `json:"generateName,omitempty" protobuf:"bytes,2,opt,name=generateName"`
// +optional
Namespace string `json:"namespace,omitempty" protobuf:"bytes,3,opt,name=namespace"`
// +optional
SelfLink string `json:"selfLink,omitempty" protobuf:"bytes,4,opt,name=selfLink"`
// +optional
UID types.UID `json:"uid,omitempty" protobuf:"bytes,5,opt,name=uid,casttype=k8s.io/kubernetes/pkg/types.UID"`
// +optional
ResourceVersion string `json:"resourceVersion,omitempty" protobuf:"bytes,6,opt,name=resourceVersion"`
// +optional
Generation int64 `json:"generation,omitempty" protobuf:"varint,7,opt,name=generation"`
// +optional
CreationTimestamp *meta.Time `json:"creationTimestamp,omitempty" protobuf:"bytes,8,opt,name=creationTimestamp"` // Modified
// +optional
DeletionTimestamp *meta.Time `json:"deletionTimestamp,omitempty" protobuf:"bytes,9,opt,name=deletionTimestamp"`
// +optional
DeletionGracePeriodSeconds *int64 `json:"deletionGracePeriodSeconds,omitempty" protobuf:"varint,10,opt,name=deletionGracePeriodSeconds"`
// +optional
Labels map[string]string `json:"labels,omitempty" protobuf:"bytes,11,rep,name=labels"`
// +optional
Annotations map[string]string `json:"annotations,omitempty" protobuf:"bytes,12,rep,name=annotations"`
// +optional
// +patchMergeKey=uid
// +patchStrategy=merge
OwnerReferences []meta.OwnerReference `json:"ownerReferences,omitempty" patchStrategy:"merge" patchMergeKey:"uid" protobuf:"bytes,13,rep,name=ownerReferences"`
// +optional
// +patchStrategy=merge
Finalizers []string `json:"finalizers,omitempty" patchStrategy:"merge" protobuf:"bytes,14,rep,name=finalizers"`
// +optional
ClusterName string `json:"clusterName,omitempty" protobuf:"bytes,15,opt,name=clusterName"`
// +optional
ManagedFields []meta.ManagedFieldsEntry `json:"managedFields,omitempty" protobuf:"bytes,17,rep,name=managedFields"`
}
ApicurioRegistryObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.
func (*ApicurioRegistryObjectMeta) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistryObjectMeta) DeepCopy() *ApicurioRegistryObjectMeta
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryObjectMeta.
func (*ApicurioRegistryObjectMeta) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistryObjectMeta) DeepCopyInto(out *ApicurioRegistryObjectMeta)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistryPodSpec ¶ added in v1.1.0
type ApicurioRegistryPodSpec struct {
// +optional
// +patchMergeKey=name
// +patchStrategy=merge,retainKeys
Volumes []core.Volume `json:"volumes,omitempty" patchStrategy:"merge,retainKeys" patchMergeKey:"name" protobuf:"bytes,1,rep,name=volumes"`
// +patchMergeKey=name
// +patchStrategy=merge
InitContainers []core.Container `json:"initContainers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,20,rep,name=initContainers"`
// +optional
// +patchMergeKey=name
// +patchStrategy=merge
Containers []core.Container `json:"containers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,2,rep,name=containers"` // Modified
// +optional
// +patchMergeKey=name
// +patchStrategy=merge
EphemeralContainers []core.EphemeralContainer `` /* 128-byte string literal not displayed */
// +optional
RestartPolicy core.RestartPolicy `json:"restartPolicy,omitempty" protobuf:"bytes,3,opt,name=restartPolicy,casttype=RestartPolicy"`
// +optional
TerminationGracePeriodSeconds *int64 `json:"terminationGracePeriodSeconds,omitempty" protobuf:"varint,4,opt,name=terminationGracePeriodSeconds"`
// +optional
ActiveDeadlineSeconds *int64 `json:"activeDeadlineSeconds,omitempty" protobuf:"varint,5,opt,name=activeDeadlineSeconds"`
// +optional
DNSPolicy core.DNSPolicy `json:"dnsPolicy,omitempty" protobuf:"bytes,6,opt,name=dnsPolicy,casttype=DNSPolicy"`
// +optional
// +mapType=atomic
NodeSelector map[string]string `json:"nodeSelector,omitempty" protobuf:"bytes,7,rep,name=nodeSelector"`
// +optional
ServiceAccountName string `json:"serviceAccountName,omitempty" protobuf:"bytes,8,opt,name=serviceAccountName"`
// +k8s:conversion-gen=false
// +optional
DeprecatedServiceAccount string `json:"serviceAccount,omitempty" protobuf:"bytes,9,opt,name=serviceAccount"`
// +optional
AutomountServiceAccountToken *bool `json:"automountServiceAccountToken,omitempty" protobuf:"varint,21,opt,name=automountServiceAccountToken"`
// +optional
NodeName string `json:"nodeName,omitempty" protobuf:"bytes,10,opt,name=nodeName"`
// +k8s:conversion-gen=false
// +optional
HostNetwork bool `json:"hostNetwork,omitempty" protobuf:"varint,11,opt,name=hostNetwork"`
// +k8s:conversion-gen=false
// +optional
HostPID bool `json:"hostPID,omitempty" protobuf:"varint,12,opt,name=hostPID"`
// +k8s:conversion-gen=false
// +optional
HostIPC bool `json:"hostIPC,omitempty" protobuf:"varint,13,opt,name=hostIPC"`
// +optional
ShareProcessNamespace *bool `json:"shareProcessNamespace,omitempty" protobuf:"varint,27,opt,name=shareProcessNamespace"`
// +optional
SecurityContext *core.PodSecurityContext `json:"securityContext,omitempty" protobuf:"bytes,14,opt,name=securityContext"`
// +optional
// +patchMergeKey=name
// +patchStrategy=merge
ImagePullSecrets []core.LocalObjectReference `json:"imagePullSecrets,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,15,rep,name=imagePullSecrets"`
// +optional
Hostname string `json:"hostname,omitempty" protobuf:"bytes,16,opt,name=hostname"`
// +optional
Subdomain string `json:"subdomain,omitempty" protobuf:"bytes,17,opt,name=subdomain"`
// +optional
Affinity *core.Affinity `json:"affinity,omitempty" protobuf:"bytes,18,opt,name=affinity"`
// +optional
SchedulerName string `json:"schedulerName,omitempty" protobuf:"bytes,19,opt,name=schedulerName"`
// +optional
Tolerations []core.Toleration `json:"tolerations,omitempty" protobuf:"bytes,22,opt,name=tolerations"`
// +optional
// +patchMergeKey=ip
// +patchStrategy=merge
HostAliases []core.HostAlias `json:"hostAliases,omitempty" patchStrategy:"merge" patchMergeKey:"ip" protobuf:"bytes,23,rep,name=hostAliases"`
// +optional
PriorityClassName string `json:"priorityClassName,omitempty" protobuf:"bytes,24,opt,name=priorityClassName"`
// +optional
Priority *int32 `json:"priority,omitempty" protobuf:"bytes,25,opt,name=priority"`
// +optional
DNSConfig *core.PodDNSConfig `json:"dnsConfig,omitempty" protobuf:"bytes,26,opt,name=dnsConfig"`
// +optional
ReadinessGates []core.PodReadinessGate `json:"readinessGates,omitempty" protobuf:"bytes,28,opt,name=readinessGates"`
// +optional
RuntimeClassName *string `json:"runtimeClassName,omitempty" protobuf:"bytes,29,opt,name=runtimeClassName"`
// +optional
EnableServiceLinks *bool `json:"enableServiceLinks,omitempty" protobuf:"varint,30,opt,name=enableServiceLinks"`
// +optional
PreemptionPolicy *core.PreemptionPolicy `json:"preemptionPolicy,omitempty" protobuf:"bytes,31,opt,name=preemptionPolicy"`
// +optional
Overhead core.ResourceList `json:"overhead,omitempty" protobuf:"bytes,32,opt,name=overhead"`
// +optional
// +patchMergeKey=topologyKey
// +patchStrategy=merge
// +listType=map
// +listMapKey=topologyKey
// +listMapKey=whenUnsatisfiable
TopologySpreadConstraints []core.TopologySpreadConstraint `` /* 147-byte string literal not displayed */
// +optional
SetHostnameAsFQDN *bool `json:"setHostnameAsFQDN,omitempty" protobuf:"varint,35,opt,name=setHostnameAsFQDN"`
// +optional
OS *core.PodOS `json:"os,omitempty" protobuf:"bytes,36,opt,name=os"`
}
ApicurioRegistryPodSpec is a description of a pod.
func (*ApicurioRegistryPodSpec) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistryPodSpec) DeepCopy() *ApicurioRegistryPodSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryPodSpec.
func (*ApicurioRegistryPodSpec) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistryPodSpec) DeepCopyInto(out *ApicurioRegistryPodSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistryPodTemplateSpec ¶ added in v1.1.0
type ApicurioRegistryPodTemplateSpec struct {
// +optional
Metadata ApicurioRegistryObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// +optional
Spec ApicurioRegistryPodSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
}
ApicurioRegistryPodTemplateSpec describes the data a pod should have when created from a template
func (*ApicurioRegistryPodTemplateSpec) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistryPodTemplateSpec) DeepCopy() *ApicurioRegistryPodTemplateSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryPodTemplateSpec.
func (*ApicurioRegistryPodTemplateSpec) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistryPodTemplateSpec) DeepCopyInto(out *ApicurioRegistryPodTemplateSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpec ¶
type ApicurioRegistrySpec struct {
// Apicurio Registry application configuration
Configuration ApicurioRegistrySpecConfiguration `json:"configuration,omitempty"`
// Apicurio Registry deployment configuration
Deployment ApicurioRegistrySpecDeployment `json:"deployment,omitempty"`
}
ApicurioRegistrySpec defines the desired state of ApicurioRegistry
func (*ApicurioRegistrySpec) DeepCopy ¶
func (in *ApicurioRegistrySpec) DeepCopy() *ApicurioRegistrySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpec.
func (*ApicurioRegistrySpec) DeepCopyInto ¶
func (in *ApicurioRegistrySpec) DeepCopyInto(out *ApicurioRegistrySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfiguration ¶
type ApicurioRegistrySpecConfiguration struct {
// Storage:
//
// Type of storage used by Apicurio Registry, one of: mem, sql, kafkasql.
// Default value is `mem`.
Persistence string `json:"persistence,omitempty"`
// Configuration of Apicurio Registry SQL storage
Sql ApicurioRegistrySpecConfigurationSql `json:"sql,omitempty"`
// Configuration of Apicurio Registry KafkaSQL storage
Kafkasql ApicurioRegistrySpecConfigurationKafkasql `json:"kafkasql,omitempty"`
// Configuration of Apicurio Registry web console
UI ApicurioRegistrySpecConfigurationUI `json:"ui,omitempty"`
// Third-party (non-Apicurio) library log level
LogLevel string `json:"logLevel,omitempty"`
// Apicurio Registry application log level
RegistryLogLevel string `json:"registryLogLevel,omitempty"`
// Security configuration
Security ApicurioRegistrySpecConfigurationSecurity `json:"security,omitempty"`
// Environment variables:
//
// List of additional environment variables that will be
// provided to the Apicurio Registry application.
Env []core.EnvVar `json:"env,omitempty"`
}
func (*ApicurioRegistrySpecConfiguration) DeepCopy ¶
func (in *ApicurioRegistrySpecConfiguration) DeepCopy() *ApicurioRegistrySpecConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfiguration.
func (*ApicurioRegistrySpecConfiguration) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfiguration) DeepCopyInto(out *ApicurioRegistrySpecConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationDataSource ¶
type ApicurioRegistrySpecConfigurationDataSource struct {
// Data source URL:
//
// URL of the PostgreSQL database, for example:
// `jdbc:postgresql://<service name>.<namespace>.svc:5432/<database name>`.
Url string `json:"url,omitempty"`
// Data source username
UserName string `json:"userName,omitempty"`
// Data source password
Password string `json:"password,omitempty"` // TODO Support Secrets
}
func (*ApicurioRegistrySpecConfigurationDataSource) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationDataSource) DeepCopy() *ApicurioRegistrySpecConfigurationDataSource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationDataSource.
func (*ApicurioRegistrySpecConfigurationDataSource) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationDataSource) DeepCopyInto(out *ApicurioRegistrySpecConfigurationDataSource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationKafkaSecurity ¶
type ApicurioRegistrySpecConfigurationKafkaSecurity struct {
// TLS:
//
// Kafka is secured using TLS.
Tls ApicurioRegistrySpecConfigurationKafkaSecurityTls `json:"tls,omitempty"`
// SCRAM:
//
// Kafka is secured using SCRAM.
Scram ApicurioRegistrySpecConfigurationKafkaSecurityScram `json:"scram,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationKafkaSecurity) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurity) DeepCopy() *ApicurioRegistrySpecConfigurationKafkaSecurity
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationKafkaSecurity.
func (*ApicurioRegistrySpecConfigurationKafkaSecurity) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurity) DeepCopyInto(out *ApicurioRegistrySpecConfigurationKafkaSecurity)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationKafkaSecurityScram ¶
type ApicurioRegistrySpecConfigurationKafkaSecurityScram struct {
// Truststore Secret name:
//
// Name of a Secret that contains TLS truststore (in PKCS12 format)
// under the `ca.p12` key, and truststore password under the `ca.password` key.
TruststoreSecretName string `json:"truststoreSecretName,omitempty"`
// User name
User string `json:"user,omitempty"`
// User password Secret name:
//
// Name of a Secret that contains password of the SCRAM user
// under the `password` key.
PasswordSecretName string `json:"passwordSecretName,omitempty"`
// Mechanism:
//
// Name of the SCRAM mechanism, default value is SCRAM-SHA-512.
Mechanism string `json:"mechanism,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationKafkaSecurityScram) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurityScram) DeepCopy() *ApicurioRegistrySpecConfigurationKafkaSecurityScram
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationKafkaSecurityScram.
func (*ApicurioRegistrySpecConfigurationKafkaSecurityScram) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurityScram) DeepCopyInto(out *ApicurioRegistrySpecConfigurationKafkaSecurityScram)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationKafkaSecurityTls ¶
type ApicurioRegistrySpecConfigurationKafkaSecurityTls struct {
// Truststore Secret name:
//
// Name of a Secret that contains TLS truststore (in PKCS12 format)
// under the `ca.p12` key, and truststore password under the `ca.password` key.
TruststoreSecretName string `json:"truststoreSecretName,omitempty"`
// Keystore Secret name:
//
// Name of a Secret that contains TLS keystore (in PKCS12 format)
// under the `user.p12` key, and keystore password under the `user.password` key.
KeystoreSecretName string `json:"keystoreSecretName,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationKafkaSecurityTls) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurityTls) DeepCopy() *ApicurioRegistrySpecConfigurationKafkaSecurityTls
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationKafkaSecurityTls.
func (*ApicurioRegistrySpecConfigurationKafkaSecurityTls) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationKafkaSecurityTls) DeepCopyInto(out *ApicurioRegistrySpecConfigurationKafkaSecurityTls)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationKafkasql ¶
type ApicurioRegistrySpecConfigurationKafkasql struct {
// Kafka bootstrap servers URL:
//
// URL of one of the Kafka brokers, which provide initial metadata about the Kafka cluster,
// for example: `<service name>.<namespace>.svc:9092`.
BootstrapServers string `json:"bootstrapServers,omitempty"`
// Kafka security configuration:
//
// Provide the following configuration options if your Kafka cluster
// is secured using TLS or SCRAM.
Security ApicurioRegistrySpecConfigurationKafkaSecurity `json:"security,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationKafkasql) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationKafkasql) DeepCopy() *ApicurioRegistrySpecConfigurationKafkasql
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationKafkasql.
func (*ApicurioRegistrySpecConfigurationKafkasql) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationKafkasql) DeepCopyInto(out *ApicurioRegistrySpecConfigurationKafkasql)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationSecurity ¶
type ApicurioRegistrySpecConfigurationSecurity struct {
// Keycloak:
//
// Configure Apicurio Registry to use Keycloak for Identity and Access Management (IAM).
Keycloak ApicurioRegistrySpecConfigurationSecurityKeycloak `json:"keycloak,omitempty"`
// HTTPS:
//
// Configure Apicurio Registry to be accessible using HTTPS.
Https ApicurioRegistrySpecConfigurationSecurityHttps `json:"https,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationSecurity) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationSecurity) DeepCopy() *ApicurioRegistrySpecConfigurationSecurity
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationSecurity.
func (*ApicurioRegistrySpecConfigurationSecurity) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationSecurity) DeepCopyInto(out *ApicurioRegistrySpecConfigurationSecurity)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationSecurityHttps ¶ added in v1.1.0
type ApicurioRegistrySpecConfigurationSecurityHttps struct {
// Disable HTTP:
//
// Disable HTTP if HTTPS is enabled.
DisableHttp bool `json:"disableHttp,omitempty"`
// HTTPS certificate and private key Secret name:
//
// Name of a Secret that contains HTTPS certificate under the `tls.crt` key,
// and the private key under the `tls.key` key.
SecretName string `json:"secretName,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationSecurityHttps) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistrySpecConfigurationSecurityHttps) DeepCopy() *ApicurioRegistrySpecConfigurationSecurityHttps
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationSecurityHttps.
func (*ApicurioRegistrySpecConfigurationSecurityHttps) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistrySpecConfigurationSecurityHttps) DeepCopyInto(out *ApicurioRegistrySpecConfigurationSecurityHttps)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationSecurityKeycloak ¶
type ApicurioRegistrySpecConfigurationSecurityKeycloak struct {
// Keycloak auth URL:
//
// URL of the Keycloak auth endpoint, must end with `/auth`.
Url string `json:"url,omitempty"`
// Keycloak realm
Realm string `json:"realm,omitempty"`
// Client ID for the REST API
ApiClientId string `json:"apiClientId,omitempty"`
// Client ID for the UI
UiClientId string `json:"uiClientId,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationSecurityKeycloak) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationSecurityKeycloak) DeepCopy() *ApicurioRegistrySpecConfigurationSecurityKeycloak
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationSecurityKeycloak.
func (*ApicurioRegistrySpecConfigurationSecurityKeycloak) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationSecurityKeycloak) DeepCopyInto(out *ApicurioRegistrySpecConfigurationSecurityKeycloak)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationSql ¶
type ApicurioRegistrySpecConfigurationSql struct {
// SQL data source
DataSource ApicurioRegistrySpecConfigurationDataSource `json:"dataSource,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationSql) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationSql) DeepCopy() *ApicurioRegistrySpecConfigurationSql
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationSql.
func (*ApicurioRegistrySpecConfigurationSql) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationSql) DeepCopyInto(out *ApicurioRegistrySpecConfigurationSql)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecConfigurationUI ¶
type ApicurioRegistrySpecConfigurationUI struct {
// Read-only:
//
// Set the web console to read-only mode.
// WARNING: This does not affect access to the Apicurio REST API.
ReadOnly bool `json:"readOnly,omitempty"`
}
func (*ApicurioRegistrySpecConfigurationUI) DeepCopy ¶
func (in *ApicurioRegistrySpecConfigurationUI) DeepCopy() *ApicurioRegistrySpecConfigurationUI
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecConfigurationUI.
func (*ApicurioRegistrySpecConfigurationUI) DeepCopyInto ¶
func (in *ApicurioRegistrySpecConfigurationUI) DeepCopyInto(out *ApicurioRegistrySpecConfigurationUI)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecDeployment ¶
type ApicurioRegistrySpecDeployment struct {
// Replicas:
//
// The required number of Apicurio Registry pods. Default value is 1.
Replicas int32 `json:"replicas,omitempty"`
// Hostname:
//
// Apicurio Registry application hostname (part of the URL without the protocol and path).
Host string `json:"host,omitempty"`
// Affinity
Affinity *core.Affinity `json:"affinity,omitempty"`
// Tolerations
Tolerations []core.Toleration `json:"tolerations,omitempty"`
// Metadata of the Apicurio Registry pod
Metadata ApicurioRegistrySpecDeploymentMetadata `json:"metadata,omitempty"`
// Apicurio Registry image:
//
// Replaces the default Apicurio Registry application image.
// Overrides the values in the REGISTRY_IMAGE_MEM, REGISTRY_IMAGE_KAFKASQL and REGISTRY_IMAGE_SQL Operator environment variables.
Image string `json:"image,omitempty"`
// Apicurio Registry image pull secrets:
//
// List of Secrets to use when pulling the Apicurio Registry image.
ImagePullSecrets []core.LocalObjectReference `json:"imagePullSecrets,omitempty"`
// Apicurio Registry managed resources:
//
// Configure how the Operator manages Kubernetes resources.
ManagedResources ApicurioRegistrySpecDeploymentManagedResources `json:"managedResources,omitempty"`
// Configure Apicurio Registry pod template:
//
// With some restrictions, the Apicurio Registry Operator forwards the data from this field
// to the corresponding "spec.template" field in the Apicurio Registry Deployment.
// This feature provides greater configuration flexibility, without the need for the Operator to natively support each use case.
// WARNING: This feature is a Technology Preview feature only.
PodTemplateSpecPreview ApicurioRegistryPodTemplateSpec `json:"podTemplateSpecPreview,omitempty"`
}
func (*ApicurioRegistrySpecDeployment) DeepCopy ¶
func (in *ApicurioRegistrySpecDeployment) DeepCopy() *ApicurioRegistrySpecDeployment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecDeployment.
func (*ApicurioRegistrySpecDeployment) DeepCopyInto ¶
func (in *ApicurioRegistrySpecDeployment) DeepCopyInto(out *ApicurioRegistrySpecDeployment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecDeploymentManagedResources ¶ added in v1.1.0
type ApicurioRegistrySpecDeploymentManagedResources struct {
// Disable Ingress:
//
// Operator will not create or manage an Ingress for Apicurio Registry, so it can be done manually.
DisableIngress bool `json:"disableIngress,omitempty"`
// Disable NetworkPolicy:
//
// Operator will not create or manage a NetworkPolicy for Apicurio Registry, so it can be done manually.
DisableNetworkPolicy bool `json:"disableNetworkPolicy,omitempty"`
// Disable PodDisruptionBudget:
//
// Operator will not create or manage a PodDisruptionBudget for Apicurio Registry, so it can be done manually.
DisablePodDisruptionBudget bool `json:"disablePodDisruptionBudget,omitempty"`
}
func (*ApicurioRegistrySpecDeploymentManagedResources) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistrySpecDeploymentManagedResources) DeepCopy() *ApicurioRegistrySpecDeploymentManagedResources
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecDeploymentManagedResources.
func (*ApicurioRegistrySpecDeploymentManagedResources) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistrySpecDeploymentManagedResources) DeepCopyInto(out *ApicurioRegistrySpecDeploymentManagedResources)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistrySpecDeploymentMetadata ¶ added in v1.1.0
type ApicurioRegistrySpecDeploymentMetadata struct {
// Annotations:
//
// Additional Apicurio Registry Pod annotations.
Annotations map[string]string `json:"annotations,omitempty"`
// Labels:
//
// Additional Apicurio Registry Pod labels.
Labels map[string]string `json:"labels,omitempty"`
}
func (*ApicurioRegistrySpecDeploymentMetadata) DeepCopy ¶ added in v1.1.0
func (in *ApicurioRegistrySpecDeploymentMetadata) DeepCopy() *ApicurioRegistrySpecDeploymentMetadata
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistrySpecDeploymentMetadata.
func (*ApicurioRegistrySpecDeploymentMetadata) DeepCopyInto ¶ added in v1.1.0
func (in *ApicurioRegistrySpecDeploymentMetadata) DeepCopyInto(out *ApicurioRegistrySpecDeploymentMetadata)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistryStatus ¶
type ApicurioRegistryStatus struct {
// Information about the Apicurio Registry application
Info ApicurioRegistryStatusInfo `json:"info,omitempty"`
// Conditions:
//
// Apicurio Registry application and Operator conditions.
Conditions []meta.Condition `json:"conditions,omitempty"`
// Managed Resources:
//
// Kubernetes resources managed by the Apicurio Registry Operator.
ManagedResources []ApicurioRegistryStatusManagedResource `json:"managedResources,omitempty"`
}
func (*ApicurioRegistryStatus) DeepCopy ¶
func (in *ApicurioRegistryStatus) DeepCopy() *ApicurioRegistryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryStatus.
func (*ApicurioRegistryStatus) DeepCopyInto ¶
func (in *ApicurioRegistryStatus) DeepCopyInto(out *ApicurioRegistryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistryStatusInfo ¶
type ApicurioRegistryStatusInfo struct {
// Apicurio Registry URL
Host string `json:"host,omitempty"`
}
func (*ApicurioRegistryStatusInfo) DeepCopy ¶
func (in *ApicurioRegistryStatusInfo) DeepCopy() *ApicurioRegistryStatusInfo
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryStatusInfo.
func (*ApicurioRegistryStatusInfo) DeepCopyInto ¶
func (in *ApicurioRegistryStatusInfo) DeepCopyInto(out *ApicurioRegistryStatusInfo)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ApicurioRegistryStatusManagedResource ¶
type ApicurioRegistryStatusManagedResource struct {
Kind string `json:"kind,omitempty"`
Name string `json:"name,omitempty"`
Namespace string `json:"namespace,omitempty"`
}
func (*ApicurioRegistryStatusManagedResource) DeepCopy ¶
func (in *ApicurioRegistryStatusManagedResource) DeepCopy() *ApicurioRegistryStatusManagedResource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApicurioRegistryStatusManagedResource.
func (*ApicurioRegistryStatusManagedResource) DeepCopyInto ¶
func (in *ApicurioRegistryStatusManagedResource) DeepCopyInto(out *ApicurioRegistryStatusManagedResource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.